@@ -75,7 +75,7 @@ function(l1_formula = 'NA',
     conv <- conv.geweke.heidel(samples_l1_param, colnames(dMatrice$Z), colnames(dMatrice$X))
     mf2 <- NULL
     class(conv) <- 'conv.diag'
-    cat('Done...\n')
+    cat('Done.\n')
 
   }else{
     mf2 <- model.frame(formula = l2_formula, data = data)
@@ -133,7 +133,6 @@ function(l1_formula = 'NA',
       samples_l1_param <- matrix(result$mcmc[[1]][,index_l1_param], ncol = 1)
     colnames(samples_l1_param) <- colnames(result$mcmc[[1]])[index_l1_param]
     
-    #anova.table <- table.ANOVA(samples_l1_param, dMatrice$X, dMatrice$Z)
     cat('Constructing ANOVA/ANCOVA tables...\n')
     anova.table <- table.ANCOVA(samples_l1_param, dMatrice$X, dMatrice$Z, samples_l2_param) # for ancova models
     coef.tables <- table.coefficients(samples_l2_param, JAGS.model$monitorl2.parameters, colnames(dMatrice$X), colnames(dMatrice$Z), 
