@@ -1,5 +1,37 @@
 JAGSgen.binNormal <-
 function (X, Z, l2_hyper, conv_speedup){
+if (is.null(Z)){
+  num_l1_v <- ncol(X)
+  inits <- new.env() # store initial values for BUGS model
+  monitorl1.parameters <- character()  # store monitors for level 1 parameters, which will be used in the computation of sum of squares
+  monitorl2.parameters <- NULL  # store monitors for level 2 parameters
+  ### generate the code for BUGS model
+  sModel <- paste("model{", sep="")
+  ### level 1 likelihood 
+  sModel <- paste(sModel,"
+  for (i in 1:n){
+    y[i] ~ dbin(y.hat[i], N[i])
+    y.hat[i] <- max(0,min(1,P[i]))
+"," logit(P[i]) <-")
+  for (i in 1:num_l1_v){
+    if (i != num_l1_v)
+      sModel <- paste(sModel,"beta",i,"*","X[i,",i,"]+",sep="")
+    else
+      sModel <- paste(sModel,"beta",i,"*","X[i,",i,"]",sep="")
+    monitorl1.parameters<-c(monitorl1.parameters, paste("beta",i,sep=""))
+  }
+  sModel <- paste(sModel,"
+  }",sep="")
+  for (j in 1:num_l1_v){
+    sModel <- paste(sModel,"
+  beta",j,"~dnorm(0,",l2_hyper[3],")",sep="")
+    s<-paste("inits$","beta",j,"<-rnorm(1)",sep="")
+    eval(parse(text=s))
+  }
+  sModel<- paste(sModel,"
+}")
+  
+}else{
   num_l1_v <- ncol(X)
   num_l2_v <- ncol(Z)
   num_id <- nrow(Z)
@@ -90,7 +122,7 @@ function (X, Z, l2_hyper, conv_speedup){
   }
   sModel<- paste(sModel,"
 }")
-  
+}
   sol.inits <- dump.format(as.list(inits))
   results <- list(inits = sol.inits, monitorl1.parameters = monitorl1.parameters, 
                   monitorl2.parameters = monitorl2.parameters, sModel = sModel)
