@@ -1,9 +1,9 @@
 table.pvalue <-
 function (coeff_table, row_indices, l1_names, l2_names){
-  if (length(l1_names) == 1 && length(l2_names) == 1) coeff_table <- matrix(coeff_table, nrow = 1) # the case that there is only one intercept 
+  if (length(l1_names) == 1 && length(l2_names) == 1) coeff_table <- data.frame(matrix(coeff_table, nrow = 1)) # the case that there is only one intercept 
   n_l1_p <- length(l1_names)
   n_l2_p <- length(l2_names)
-  ptable <- matrix(NA, nrow =  n_l1_p, ncol = n_l2_p)
+  ptable <- data.frame(matrix(NA, nrow =  n_l1_p, ncol = n_l2_p))
   for (i in 1:n_l1_p)
     for (j in 1:n_l2_p){
       # find rows in coeff_table corresponding to each factor or interaction
@@ -14,7 +14,8 @@ function (coeff_table, row_indices, l1_names, l2_names){
       # find the p-values of corresponding variables with min and max mean 
       p_min <- temp_pvalues[which.min(temp_mean)]
       p_max <- temp_pvalues[which.max(temp_mean)]
-      ptable[i, j] <- min(p_min, p_max)
+      ptable[i, j] <- round(min(p_min, p_max), digits = 4)
+      if (ptable[i, j] == 0) ptable[i, j] <- '<0.0001' else ptable[i, j] <- format(as.numeric(ptable[i, j]), nsmall = 4)
     }
   rownames(ptable) <- l1_names
   colnames(ptable) <- l2_names
